==> jc-1.4.0.tar.gz: javax/swing/Box__24Filler.h <==
// public class javax.swing.Box$Filler

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5c9b4f50df9958c7 javax_swing_Box__24Filler
// @dep_class 6c83b58ef8abc63e javax_swing_JComponent

// header file dependencies
// @dep_header javax_swing_JComponent

#include "javax/swing/JComponent.h"

#ifndef _JC_javax_swing_Box__24Filler_H_
#define _JC_javax_swing_Box__24Filler_H_

// Forward structure declarations
struct _jc_java_awt_Dimension$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleContext$object;

// Typedefs
typedef struct _jc_javax_swing_Box__24Filler$sub_refs	_jc_javax_swing_Box__24Filler$sub_refs;
typedef struct _jc_javax_swing_Box__24Filler$sub_nonrefs	_jc_javax_swing_Box__24Filler$sub_nonrefs;
typedef struct _jc_javax_swing_Box__24Filler$refs	_jc_javax_swing_Box__24Filler$refs;
typedef struct _jc_javax_swing_Box__24Filler$nonrefs	_jc_javax_swing_Box__24Filler$nonrefs;
typedef struct _jc_javax_swing_Box__24Filler$object	_jc_javax_swing_Box__24Filler$object;

typedef struct _jc_javax_swing_Box__24Filler$fields_struct	_jc_javax_swing_Box__24Filler$fields_struct;
typedef const struct _jc_javax_swing_Box__24Filler$vmethods	_jc_javax_swing_Box__24Filler$vmethods;
typedef const struct _jc_javax_swing_Box__24Filler$vtable	_jc_javax_swing_Box__24Filler$vtable;
typedef const struct _jc_javax_swing_Box__24Filler$vtype	_jc_javax_swing_Box__24Filler$vtype;

// Class fields structure
struct _jc_javax_swing_Box__24Filler$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_Box__24Filler$fields_struct _jc_javax_swing_Box__24Filler$class_fields;

// Constructors
extern void _jc_javax_swing_Box__24Filler$method$_init$e3d82ba50ee14aaa(_jc_env *, struct _jc_javax_swing_Box__24Filler$object *, struct _jc_java_awt_Dimension$object *, struct _jc_java_awt_Dimension$object *, struct _jc_java_awt_Dimension$object *);

// Virtual methods
extern void _jc_javax_swing_Box__24Filler$method$changeShape$da8dcad33a35104b(_jc_env *, struct _jc_javax_swing_Box__24Filler$object *, struct _jc_java_awt_Dimension$object *, struct _jc_java_awt_Dimension$object *, struct _jc_java_awt_Dimension$object *);
extern struct _jc_javax_accessibility_AccessibleContext$object *_jc_javax_swing_Box__24Filler$method$getAccessibleContext$99df33b6e138b2ea(_jc_env *, struct _jc_javax_swing_Box__24Filler$object *);
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_Box__24Filler$method$getMaximumSize$d24ee7fdb96c1fa3(_jc_env *, struct _jc_javax_swing_Box__24Filler$object *);
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_Box__24Filler$method$getMinimumSize$f439289f02165af0(_jc_env *, struct _jc_javax_swing_Box__24Filler$object *);
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_Box__24Filler$method$getPreferredSize$4730bc91c97b24d9(_jc_env *, struct _jc_javax_swing_Box__24Filler$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_Box__24Filler$method_info$changeShape$da8dcad33a35104b;
extern _jc_method _jc_javax_swing_Box__24Filler$method_info$getAccessibleContext$99df33b6e138b2ea;
extern _jc_method _jc_javax_swing_Box__24Filler$method_info$getMaximumSize$d24ee7fdb96c1fa3;
extern _jc_method _jc_javax_swing_Box__24Filler$method_info$getMinimumSize$f439289f02165af0;
extern _jc_method _jc_javax_swing_Box__24Filler$method_info$getPreferredSize$4730bc91c97b24d9;

// Virtual methods structure
struct _jc_javax_swing_Box__24Filler$vmethods {
	void	(*changeShape$da8dcad33a35104b)(_jc_env *, struct _jc_javax_swing_Box__24Filler$object *, struct _jc_java_awt_Dimension$object *, struct _jc_java_awt_Dimension$object *, struct _jc_java_awt_Dimension$object *);
	struct _jc_javax_accessibility_AccessibleContext$object	*(*getAccessibleContext$99df33b6e138b2ea)(_jc_env *, struct _jc_javax_swing_Box__24Filler$object *);
	struct _jc_java_awt_Dimension$object	*(*getMaximumSize$d24ee7fdb96c1fa3)(_jc_env *, struct _jc_javax_swing_Box__24Filler$object *);
	struct _jc_java_awt_Dimension$object	*(*getMinimumSize$f439289f02165af0)(_jc_env *, struct _jc_javax_swing_Box__24Filler$object *);
	struct _jc_java_awt_Dimension$object	*(*getPreferredSize$4730bc91c97b24d9)(_jc_env *, struct _jc_javax_swing_Box__24Filler$object *);
};

// Vtable
struct _jc_javax_swing_Box__24Filler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_Box__24Filler$vmethods	javax_swing_Box__24Filler;
};

// Vtype
struct _jc_javax_swing_Box__24Filler$vtype {
	_jc_type			type;
	_jc_javax_swing_Box__24Filler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_Box__24Filler$sub_refs {
	struct _jc_javax_accessibility_AccessibleContext$object	*accessibleContext;
	struct _jc_java_awt_Dimension$object	*min;
	struct _jc_java_awt_Dimension$object	*pref;
	struct _jc_java_awt_Dimension$object	*max;
};

// Reference instance fields (object)
struct _jc_javax_swing_Box__24Filler$refs {
    _jc_javax_swing_Box__24Filler$sub_refs	javax_swing_Box__24Filler;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_Box__24Filler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_Box__24Filler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_Box__24Filler$sub_nonrefs	javax_swing_Box__24Filler;
};

// Object instance structure
struct _jc_javax_swing_Box__24Filler$object {
	_jc_javax_swing_Box__24Filler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_Box__24Filler$vtype	*vtype;
	_jc_javax_swing_Box__24Filler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_Box__24Filler$vtype _jc_javax_swing_Box__24Filler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_Box__24Filler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_Box__24Filler$class_object;

#endif	/* _JC_javax_swing_Box__24Filler_H_ */

==> jc-1.4.5.tar.gz: javax/swing/Box__24Filler.h <==
// public class javax.swing.Box$Filler

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5c9b4f50df9958c7 javax_swing_Box__24Filler
// @dep_class c84352ee73c7cec1 javax_swing_JComponent

// header file dependencies
// @dep_header javax_swing_JComponent

#include "javax/swing/JComponent.h"

#ifndef _JC_javax_swing_Box__24Filler_H_
#define _JC_javax_swing_Box__24Filler_H_

// Forward structure declarations
struct _jc_java_awt_Dimension$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleContext$object;

// Typedefs
typedef struct _jc_javax_swing_Box__24Filler$sub_refs	_jc_javax_swing_Box__24Filler$sub_refs;
typedef struct _jc_javax_swing_Box__24Filler$sub_nonrefs	_jc_javax_swing_Box__24Filler$sub_nonrefs;
typedef struct _jc_javax_swing_Box__24Filler$refs	_jc_javax_swing_Box__24Filler$refs;
typedef struct _jc_javax_swing_Box__24Filler$nonrefs	_jc_javax_swing_Box__24Filler$nonrefs;
typedef struct _jc_javax_swing_Box__24Filler$object	_jc_javax_swing_Box__24Filler$object;

typedef struct _jc_javax_swing_Box__24Filler$fields_struct	_jc_javax_swing_Box__24Filler$fields_struct;
typedef const struct _jc_javax_swing_Box__24Filler$vmethods	_jc_javax_swing_Box__24Filler$vmethods;
typedef const struct _jc_javax_swing_Box__24Filler$vtable	_jc_javax_swing_Box__24Filler$vtable;
typedef const struct _jc_javax_swing_Box__24Filler$vtype	_jc_javax_swing_Box__24Filler$vtype;

// Class fields structure
struct _jc_javax_swing_Box__24Filler$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_Box__24Filler$fields_struct _jc_javax_swing_Box__24Filler$class_fields;

// Constructors
extern void _jc_javax_swing_Box__24Filler$method$_init$e3d82ba50ee14aaa(_jc_env *, struct _jc_javax_swing_Box__24Filler$object *, struct _jc_java_awt_Dimension$object *, struct _jc_java_awt_Dimension$object *, struct _jc_java_awt_Dimension$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_Box__24Filler$method$changeShape$da8dcad33a35104b(_jc_env *, struct _jc_javax_swing_Box__24Filler$object *, struct _jc_java_awt_Dimension$object *, struct _jc_java_awt_Dimension$object *, struct _jc_java_awt_Dimension$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_accessibility_AccessibleContext$object *_jc_javax_swing_Box__24Filler$method$getAccessibleContext$99df33b6e138b2ea(_jc_env *, struct _jc_javax_swing_Box__24Filler$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_Box__24Filler$method$getMaximumSize$d24ee7fdb96c1fa3(_jc_env *, struct _jc_javax_swing_Box__24Filler$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_Box__24Filler$method$getMinimumSize$f439289f02165af0(_jc_env *, struct _jc_javax_swing_Box__24Filler$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_Box__24Filler$method$getPreferredSize$4730bc91c97b24d9(_jc_env *, struct _jc_javax_swing_Box__24Filler$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_Box__24Filler$method_info$changeShape$da8dcad33a35104b;
extern _jc_method _jc_javax_swing_Box__24Filler$method_info$getAccessibleContext$99df33b6e138b2ea;
extern _jc_method _jc_javax_swing_Box__24Filler$method_info$getMaximumSize$d24ee7fdb96c1fa3;
extern _jc_method _jc_javax_swing_Box__24Filler$method_info$getMinimumSize$f439289f02165af0;
extern _jc_method _jc_javax_swing_Box__24Filler$method_info$getPreferredSize$4730bc91c97b24d9;

// Virtual methods structure
struct _jc_javax_swing_Box__24Filler$vmethods {
	void	(*changeShape$da8dcad33a35104b)(_jc_env *, struct _jc_javax_swing_Box__24Filler$object *, struct _jc_java_awt_Dimension$object *, struct _jc_java_awt_Dimension$object *, struct _jc_java_awt_Dimension$object *) _JC_JCNI_ATTR;
	struct _jc_javax_accessibility_AccessibleContext$object	*(*getAccessibleContext$99df33b6e138b2ea)(_jc_env *, struct _jc_javax_swing_Box__24Filler$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Dimension$object	*(*getMaximumSize$d24ee7fdb96c1fa3)(_jc_env *, struct _jc_javax_swing_Box__24Filler$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Dimension$object	*(*getMinimumSize$f439289f02165af0)(_jc_env *, struct _jc_javax_swing_Box__24Filler$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Dimension$object	*(*getPreferredSize$4730bc91c97b24d9)(_jc_env *, struct _jc_javax_swing_Box__24Filler$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_Box__24Filler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_Box__24Filler$vmethods	javax_swing_Box__24Filler;
};

// Vtype
struct _jc_javax_swing_Box__24Filler$vtype {
	_jc_type			type;
	_jc_javax_swing_Box__24Filler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_Box__24Filler$sub_refs {
	struct _jc_javax_accessibility_AccessibleContext$object	*accessibleContext;
	struct _jc_java_awt_Dimension$object	*min;
	struct _jc_java_awt_Dimension$object	*pref;
	struct _jc_java_awt_Dimension$object	*max;
};

// Reference instance fields (object)
struct _jc_javax_swing_Box__24Filler$refs {
    _jc_javax_swing_Box__24Filler$sub_refs	javax_swing_Box__24Filler;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_Box__24Filler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_Box__24Filler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_Box__24Filler$sub_nonrefs	javax_swing_Box__24Filler;
};

// Object instance structure
struct _jc_javax_swing_Box__24Filler$object {
	_jc_javax_swing_Box__24Filler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_Box__24Filler$vtype	*vtype;
	_jc_javax_swing_Box__24Filler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_Box__24Filler$vtype _jc_javax_swing_Box__24Filler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_Box__24Filler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_Box__24Filler$class_object;

#endif	/* _JC_javax_swing_Box__24Filler_H_ */
